Range-v3: ranges::v3::partial_sort_fn Struct Reference

Range-v3 Range algorithms, views, and actions for the Standard Library |

Public Member Functions | List of all members
ranges::v3::partial_sort_fn Struct Reference
Algorithms

## Public Member Functions
template<typename I , typename S , typename C = ordered_less, typename P = ident, requires = (Sortable<I, C, P>() && RandomAccessIterator<I>() && Sentinel<S, I>())>
I | operator() (I begin, I middle, S end, C pred=C{}, P proj=P{}) const
template<typename Rng , typename C = ordered_less, typename P = ident, typename I = iterator_t<Rng>, requires = (Sortable<I, C, P>() && RandomAccessRange<Rng>())>
safe_iterator_t< Rng > | operator() (Rng &&rng, I middle, C pred=C{}, P proj=P{}) const